# Change Log

## 0.9.1

Release on June 14,2023

* cgc billing - updated which values from response are taken to show
  * cost_total in billing was shown correctly - no changes
  * start, end, time: updated with correct key:value pairs from response

## 0.9.0

Release on June 13, 2023.

* APP TLS update - DNS for API endpoint
* removed self signed certificate, server got signed certificate for cgc-api.comtegra.cloud
* added new compose template: label-studio
* default user for label-studio: admin@localhost
* default user for filebrowser: admin
* default user for postgresql: admin

## 0.8.8, 0.8.9

Release on May 29, 2023.

* hotfix: fixed redis import in cgc.sdk

## 0.8.7

Release on May 23, 2023.

* hotfix: development changed .env file making it broken for new users

## 0.8.6

Release on May 19, 2023.

* added get_redis_client_async() for RedisConnector
* get_redis_access() - async_client: bool, new parameter
* new command: cgc context switch [number]
  * switch between user contexts
* new command: cgc context list
  * list all configuration files
* updated command: cgc register
  * allow to have multiple user contexts
* increased timeout for requests to 30 sec

## 0.8.5

Release on Apr 21, 2023.

* update for cgc status: resource_keys in cgc_status_response

## 0.8.4

Release on Apr 18, 2023.

* fix regarding missing imports

## 0.8.3

Release on Apr 18, 2023.

* minor db sdk update
* added restart optional parameter to client

## 0.8.2

Release on Apr 18, 2023.

* minor bug fixes

## 0.8.1

Release on Apr 17, 2023.

* cgc db list
* cgc compute list
* cgc events APP_NAME
* package cgc.sdk for management of databases templates inside user namespace

## 0.8.0

Release on Apr 14, 2023.

* cgc db - new commands for managing databases
* cgc compute - refactor commands for compute template management
* cgc resource - new command to control db and compute resources

## 0.7.1

Released on Mar 23, 2023.

* endpoints can be disabled on server, client correctly understand error code 302
* api-keys management endpoints are temporary disabled (list, delete)

## 0.7.0

Released on Mar 22, 2023.

* volume host group removed
* added telemetry opt-in/opt-out
* billing cost is set (update cost values for usage)
* storage layout on Kubernetes cluster
* billing usage in namespace managed with multiple users
* triton server enabled to create

## 0.6.7

Released on Mar 10, 2023.

* debug commands group added
* opt-in telemetry for the first time

## 0.6.6

Released on March 03, 2023.

* updated standard error message
* updated version control message
* with `cgc volume create` parameter `-g` is now `-hg`, which is host group
* help message for parameters
* DATASCIENCE_JUPYTER, TENSORFLOW_JUPYTER removed
* telemetry codes updated (fail only on APP errors (client/server))

## 0.6.5

Released on Feb 20, 2023.
Changes from 0.6.0 to 0.6.5

* updated command `cgc api-key create`
* updated command `cgc register`
* updated command `cgc compute list`

## 0.6.0

Released on Feb 15, 2023.

### Added

* TLS support using SSL certificate
* self-signed `server.crt` by Comtegra S.A developers (until another certificate is used)
* server from version **0.6.0** requires *TLS* over *HTTPS*
* utils for handling connection to server with error handling
* utils for server response with error handling
* extra decorator for message parser which catches errors while decoding Json response
  * TypeError
  * KeyError
  * Custom Comtegra exceptions
* Tests for CLI
* `cgc api-key create` - allows to create new API-key pair for current user-id. Currently overwrites existing

### Changed

* Code refactor - created decorators, better exception handling, functions for repeatable tasks
  * `cgc compute` commands
  * `cgc volume` commands
  * `cgc billing` commands
  * `cgc register` commands
* Bug fix - `cgc volume umount <vol_name> -t <app_name>` now correctly unmounts ONLY from that app
  * Endpoint now validates -t as a list of strings which is required to hold mount for every app - unmount from all in list or None
  * Passing None (or not passing -t in CLI client) will unmount from all apps holding this volume
  * Fixed messages displayed on client and responses from server
* Response messages for `cgc compute create` now better describes current status
* Error responses messages are now generated by server, can be displayed by client
* Client error handling
* Allowed GPU's: A100, A5000
* Volume create - HDD disabled temporary

### Removed

* Unnecessary blocks of code
* Temporary removed support for V100
* `cgc login` - same functionality (and updated) available through `cgc api-key create`

## 0.5.3

No changelog for this and previous releases.
